@@ -20,7 +20,7 @@
 # ============================================================================
 # Name        : sleeppy.py
 # Author      : Vadim Karpusenko < vadikus gmail com >
-# Version     : 0.1
+# Version     : 0.2
 # Description : Python Hildon SleepPy Patterns
 # ============================================================================
 #
@@ -60,52 +60,12 @@ import ConfigParser
 import os, os.path
 import datetime
 import time
-#import pygst
-#import gst
 import alarm
 import gobject
 import gettext
 import locale
 import math
-
-
-APP_NAME = "SleepPy"
-gettext.install(APP_NAME)
-
-# TODO: migrate to gettext
-#local_path = os.path.realpath(os.path.dirname(sys.argv[0]))
-## Init the list of languages to support
-#langs = []
-##Check the default locale
-#lc, encoding = locale.getdefaultlocale()
-#if (lc):
-#    #If we have a default, it's the first in the list
-#    langs = [lc]
-## Now lets get all of the supported languages on the system
-#language = os.environ.get('LANGUAGE', None)
-#if (language):
-#    """langage comes back something like en_CA:en_US:en_GB:en
-#    on linuxy systems, on Win32 it's nothing, so we need to
-#    split it up into a list"""
-#    langs += language.split(":")
-#"""Now add on to the back of the list the translations that we
-#know that we have, our defaults"""
-#langs += ["ru_RU", "en_US"]
-#
-#"""Now langs is a list of all of the languages that we are going
-#to try to use.  First we check the default, then what the system
-#told us, and finally the 'known' list"""
-#
-#gettext.bindtextdomain(APP_NAME, self.local_path)
-#gettext.textdomain(APP_NAME)
-## Get the language to use
-#self.lang = gettext.translation(APP_NAME, self.local_path
-#    , languages=langs, fallback = True)
-#"""Install the language, map _() (which we marked our
-#strings to translate with) to self.lang.gettext() which will
-#translate them."""
-#_ = self.lang.gettext
-
+import sys
 
 defdir = '/home/user/MyDocs/sleeppy'
 config = ConfigParser.SafeConfigParser()
@@ -132,294 +92,33 @@ else:
     config.add_section('tech')
     config.set('tech', 'average', '100')
     config.set('tech', 'accelerometr', "/sys/class/i2c-adapter/i2c-3/3-001d/coord")
-    config.set('tech', 'pause', '0.01')
-    
-    config.add_section('rus')
-    config.add_section('eng')
-    config.set('rus', 'name', u'Мониторинг Сна')
-    config.set('eng', 'name', 'SleepPy Patterns')
-    config.set('rus', 'button_alarm', u"""Нажмите для начала записи статистики.""")
-    config.set('eng', 'button_alarm', """Click here to start gethering statistics""")
-    config.set('rus', 'button_alarm_stop', u'Нажмите опять для остановки сбора статистики\nЗапись идёт в файл:\n')
-    config.set('eng', 'button_alarm_stop', 'Press to stop statistics gethering\nLoggin to the file:\n') 
-    config.set('rus', 'alarm_title', u'Будильник для лучшего просыпания')
-    config.set('eng', 'alarm_title', 'Alarm for easier wake up')
-    config.set('rus', 'hours', u" часов")
-    config.set('eng', 'hours', ' hours')
-    config.set('rus', 'button_duration', u"Задать длительность сна")
-    config.set('eng', 'button_duration', 'Set sleep duration')
-    config.set('rus', 'button_time', u"Задать время подъёма")
-    config.set('eng', 'button_time', 'Set alarm time')
-    config.set('rus', 'statistics', u"Статистика")
-    config.set('eng', 'statistics', 'Statistics')
-    config.set('rus', 'button_statistics', u"Данные о качестве сна")
-    config.set('eng', 'button_statistics', 'Sleep quality data')
-    config.set('rus', 'wake_up', u'Просыпайся! Покажи миру на что ты способен!')
-    config.set('eng', 'wake_up', 'Wake Up! Go, get them, Tiger!')
-    config.set('rus', 'stop', u'Отключить')
-    config.set('eng', 'stop', 'Stop')
-    config.set('rus', 'snooze', u'Подремать')
-    config.set('eng', 'snooze', 'Snooze')
-    config.set('rus', 'minutes', u'мин.')
-    config.set('eng', 'minutes', 'min')
-    config.set('rus', 'time_button', u'Время обязательного подъёма')
-    config.set('eng', 'time_button', 'Required wake up time')
-    config.set('rus', 'interval_lable', u'Временной интервал пробуждения (в минутах)')
-    config.set('eng', 'interval_lable', 'Wake up time interval (minutes)')
-    config.set('rus', 'duration', u'Необходимая длительность сна (в часах)')
-    config.set('eng', 'duration', 'Required sleep duration (hours)')        
+    config.set('tech', 'pause', '0.01')      
 
     os.mkdir(defdir)
-    with open(defdir+'/sleeppy-0001.log', 'w') as f:
-        f.write("""# 2010-04-14 23:04:36
-  0.0036 477.000
-  0.0044 437.454
-  0.0047 145.115
-  0.0050 191.915
-  0.0053 126.466
-  0.0056 468.179
-  0.0058 144.553
-  0.0064 398.064
-  0.0072 381.072
-  0.0072 227.703
-  0.0075 389.077
-  0.0078 319.221
-  0.0081 816.285
-  0.0097 619.848
-  0.0117 266.352
-  0.0119 702.015
-  0.0122 263.296
-  0.0125 122.756
-  0.1103 110.604
-  0.1108 485.935
-  0.1111 189.630
-  0.1114 327.724
-  0.1117 190.806
-  0.1119 136.293
-  0.1122 222.404
-  0.1125 395.129
-  0.1142 117.478
-  0.1142 113.357
-  0.1150 100.339
-  0.1153 180.934
-  0.1228 245.912
-  0.1233 226.968
-  0.1481 139.675
-  0.1539 202.119
-  0.1544 105.050
-  0.1553 179.047
-  0.1561 319.761
-  0.1561 146.166
-  0.1567 109.979
-  0.1567 104.180
-  0.1569 125.877
-  0.1572 258.478
-  0.1578 135.685
-  0.1578 126.383
-  0.1581 409.679
-  0.1617 151.794
-  0.1617 122.863
-  0.1622 128.936
-  0.1644 113.949
-  0.1681 208.148
-  0.1681 133.204
-  0.2139 101.445
-  0.2142 206.882
-  0.2147 109.847
-  0.2147 363.736
-  0.2150 168.608
-  0.2153 118.567
-  0.2350 239.624
-  0.2353 111.103
-  0.2356 154.303
-  0.2358 118.504
-  0.2361 403.868
-  0.2364 554.143
-  0.2367 264.115
-  0.2378 108.070
-  0.2492 252.132
-  0.2494 123.821
-  0.2808 153.079
-  0.2822 204.350
-  0.2833 190.846
-  0.2994 238.063
-  0.2994 304.000
-  0.2997 216.643
-  0.3547 257.165
-  0.3553 131.229
-  0.3556 524.882
-  0.3558 189.801
-  0.3561 617.686
-  0.3564 499.531
-  0.3567 195.625
-  0.3572 220.668
-  0.3572 141.055
-  0.3575 153.888
-  0.3578 187.096
-  0.3581 103.926
-  0.3586 422.564
-  0.3586 176.073
-  1.3975 141.297
-  1.3983 105.663
-  1.3997 101.582
-  1.4000 184.671
-  1.4003 265.141
-  1.4014 164.196
-  1.6897 162.004
-  2.2986 109.606
-  2.7250 207.490
-  2.7253 108.910
-  2.7269 105.284
-  2.7275 112.255
-  2.7275 111.028
-  2.7278 222.023
-  2.7289 167.154
-  2.7289 273.436
-  2.7297 197.673
-  2.7317 115.853
-  2.7317 161.100
-  2.7319 408.176
-  3.3139 264.244
-  3.4225 143.187
-  3.4231 140.608
-  3.4233 378.161
-  3.4236 270.024
-  3.4239 432.009
-  3.4242 414.052
-  3.4244 576.612
-  3.4247 372.385
-  3.4250 402.070
-  3.4253 207.429
-  3.4256 539.099
-  3.4769 147.149
-  3.5094 447.788
-  3.5225 199.098
-  3.6678 234.009
-  3.6681 516.545
-  3.7981 119.863
-  3.7983 124.073
-  3.7986 102.917
-  4.3708 227.677
-  4.3708 161.026
-  4.3711 581.570
-  4.3714 472.430
-  4.6567 267.436
-  4.6569 158.687
-  4.6581 358.597
-  4.9317 187.530
-  4.9319 144.798
-  4.9911 119.660
-  4.9914 138.610
-  4.9919 129.333
-  5.0878 130.495
-  5.0881 115.482
-  5.0883 399.418
-  5.0886 150.488
-  5.4989 179.209
-  5.4994 439.709
-  5.4997 365.170
-  5.8442 332.959
-  6.2231 443.551
-  6.2497 380.463
-  6.2683 156.777
-  6.3931 175.355
-  6.3939 105.529
-  6.3942 101.131
-  6.3944 101.707
-  6.3947 106.582
-  6.3950 397.914
-  6.3953 1302.469
-  6.3956 1067.468
-  7.1125 118.404
-  7.4864 295.324
-  7.4978 102.650
-  7.4986 107.179
-  7.4986 155.057
-  7.4989 370.962
-  7.7369 284.962
-  7.7369 249.755
-  7.7375 132.127
-  7.8172 153.477
-  7.9356 121.858
-  7.9369 146.673
-  7.9372 827.187
-  7.9375 315.333
-  7.9378 263.045
-  7.9381 623.806
-  7.9383 364.351
-  7.9386 208.922
-  7.9389 1172.658
-  7.9392 409.733
-  7.9394 561.339
-  7.9397 395.542
-  7.9986 112.599
-  8.1503 123.452
-  8.1511 173.403
-  8.1514 431.316
-  8.1517 237.259
-  8.2122 170.749
-  8.2128 328.002
-  8.2128 132.886
-  8.2133 193.815
-  8.2136 456.281
-  8.2139 399.140
-  8.2939 167.370
-  8.2942 109.546
-  8.2944 141.935
-  8.2950 109.126
-  8.2950 789.141
-  8.3844 530.187
-  8.3847 294.117
-  8.3850 134.648
-  8.3853 144.186
-  8.3856 458.676
-  8.5161 364.420
-  8.5164 152.787
-  8.5178 200.644
-  8.5181 455.643
-  8.5183 346.956
-  9.0228 158.601
-  9.0231 405.579
-  9.1561 136.069
-  9.2781 517.708
-  9.2783 152.842
-  9.2794 121.035
-  9.2803 102.471
-  9.2806 183.141
-  9.2808 195.533
-  9.3631 104.296
-  9.3639 190.749
-  9.3642 129.331
-  9.4869 107.945
-  9.4875 226.479
-  9.4875 132.147
-  9.4878 845.868
-  9.4881 668.945
-  9.4883 176.560
-  9.4886 187.322
-  9.5761 216.211
-  9.5764 174.786
-  9.5767 117.623
-  9.7289 106.999
-  9.7292 134.097
-  9.7306 101.598
-  9.7311 127.112
-  9.7317 283.058
-  9.7319 170.815
-  9.7322 182.226
-  9.7325 483.905
-  9.7328 250.508
-  9.7331 167.153
-  9.7333 423.180
-  9.7336 416.933
-  9.7339 934.469
-  9.7344 444.880
-  9.9247 134.694
-  9.9261 117.198
-  9.9264 584.951
- 10.5989 237.638 """)
-
+    
 border = 2
+
+APP_NAME = "SleepPy"
+gettext.install(APP_NAME)
+
+local_path = os.path.realpath(os.path.dirname(sys.argv[0]))
+langs = []
+lc, encoding = locale.getdefaultlocale()
+if (lc):
+    langs = [lc]
+language = os.environ.get('LANGUAGE', None)
+if (language):
+    langs += language.split(":")
+langs += ["en_US", "ru_RU"]
+        
+if config.get('user', 'language') == 'rus':
+    langs = ["ru_RU"]
+
+gettext.bindtextdomain(APP_NAME, local_path)
+gettext.textdomain(APP_NAME)
+lang = gettext.translation(APP_NAME, local_path
+    , languages=langs, fallback = True)
+_ = lang.gettext
     
 class SleepPyPatterns(hildon.Program):
     def __init__(self):
@@ -428,9 +127,8 @@ class SleepPyPatterns(hildon.Program):
         self.window = hildon.StackableWindow()
         self.window.connect("delete_event", self.quit)  
         self.add_window(self.window)
-        
-        self.lang = config.get('user', 'language')
-        gtk.set_application_name(config.get(self.lang, 'name'))
+                    
+        gtk.set_application_name(_('SleepPy Patterns'))
         
         vbox = gtk.VBox(False, border)
         vbox.set_border_width(border)
@@ -453,8 +151,8 @@ class SleepPyPatterns(hildon.Program):
         
         self.button_alarm = hildon.Button(gtk.HILDON_SIZE_AUTO, 
                                hildon.BUTTON_ARRANGEMENT_VERTICAL, 
-                               config.get(self.lang, 'alarm_title'),
-                               config.get(self.lang, 'button_alarm') 
+                               _('Alarm for easier wake up'),
+                               _('Click here to start gethering statistics') 
                                )
         #button_alarm.set_style(hildon.BUTTON_STYLE_PICKER)
         self.button_alarm.connect('pressed', self.main)
@@ -464,20 +162,20 @@ class SleepPyPatterns(hildon.Program):
 
         self.button_duration = hildon.Button(gtk.HILDON_SIZE_THUMB_HEIGHT, 
                                hildon.BUTTON_ARRANGEMENT_VERTICAL, 
-                               config.get('user', 'duration')+' '+config.get(self.lang, 'hours'), 
-                               config.get(self.lang, 'button_duration'))
+                               config.get('user', 'duration')+' '+_('hours'), 
+                               _('Set sleep duration'))
         self.button_duration.connect('clicked', self.duration_dialog)
         
         self.button_time = hildon.Button(gtk.HILDON_SIZE_THUMB_HEIGHT, 
                                hildon.BUTTON_ARRANGEMENT_VERTICAL, 
                                config.get('user', 'alarm'), 
-                               config.get(self.lang, 'button_time'))
+                               _('Set alarm time'))
         self.button_time.connect('clicked', self.time_dialog)
 
         self.button_statistics = hildon.Button(gtk.HILDON_SIZE_THUMB_HEIGHT, 
                                hildon.BUTTON_ARRANGEMENT_VERTICAL, 
-                               config.get(self.lang, 'statistics'),
-                               config.get(self.lang, 'button_statistics'))
+                               _('Statistics'),
+                               _('Sleep quality data'))
         self.button_statistics.connect("clicked", self.test_win)#self.show_stat_window)
         
         image_statistics = gtk.image_new_from_stock(gtk.STOCK_EXECUTE, gtk.ICON_SIZE_BUTTON)
@@ -497,13 +195,12 @@ class SleepPyPatterns(hildon.Program):
     def test_win(self, wiget):
         # Create a new backing pixmap of the appropriate size
         def configure_event(widget, event):
-            global pixmap
 
             gc = widget.window.new_gc()
             gc.set_rgb_fg_color(gtk.gdk.color_parse("#222222"))
             x, y, width, height = widget.get_allocation()
-            pixmap = gtk.gdk.Pixmap(widget.window, width, height)
-            pixmap.draw_rectangle(gc, #widget.get_style().white_gc,
+            self.pixmap[widget] = gtk.gdk.Pixmap(widget.window, width, height)
+            self.pixmap[widget].draw_rectangle(gc, #widget.get_style().white_gc,
                                   True, 0, 0, width, height)
         
             return True
@@ -512,7 +209,8 @@ class SleepPyPatterns(hildon.Program):
         def expose_event(widget, event):
             x , y, width, height = event.area
             widget.window.draw_drawable(widget.get_style().fg_gc[gtk.STATE_NORMAL],
-                                        pixmap, x, y, x, y, width, height)
+                                        self.pixmap[widget], x, y, x, y, 
+                                        width, height)
             return False
         
         # Draw a rectangle on the screen
@@ -522,7 +220,7 @@ class SleepPyPatterns(hildon.Program):
             gc.set_rgb_fg_color(gtk.gdk.color_parse("#AAAAAA"))
 
             rect = (int(x-5), int(y-5), 10, 10)
-            pixmap.draw_rectangle(gc, #widget.get_style().bg_gc, 
+            self.pixmap[widget].draw_rectangle(gc, #widget.get_style().bg_gc, 
                                   True,
                                   rect[0], rect[1], rect[2], rect[3])
             widget.queue_draw_area(rect[0], rect[1], rect[2], rect[3])
@@ -533,7 +231,7 @@ class SleepPyPatterns(hildon.Program):
             gc.set_rgb_fg_color(gtk.gdk.Color(y, y, y, 0))
 
             rect = (int(x-width), 0, int(width)+1, 500)
-            pixmap.draw_rectangle(gc, #widget.get_style().bg_gc, 
+            self.pixmap[widget].draw_rectangle(gc, #widget.get_style().bg_gc, 
                                   True,
                                   rect[0], rect[1], rect[2], rect[3])
             widget.queue_draw_area(rect[0], rect[1], rect[2], rect[3])
@@ -544,7 +242,7 @@ class SleepPyPatterns(hildon.Program):
             gc.set_rgb_fg_color(gtk.gdk.color_parse("#555555"))
 
             rect = (int(x-1), int(y), 3, 500)
-            pixmap.draw_rectangle(gc, #widget.get_style().bg_gc, 
+            self.pixmap[widget].draw_rectangle(gc, #widget.get_style().bg_gc, 
                                   True,
                                   rect[0], rect[1], rect[2], rect[3])
             widget.queue_draw_area(rect[0], rect[1], rect[2], rect[3])
@@ -577,13 +275,16 @@ class SleepPyPatterns(hildon.Program):
 #            return True            
 
         window = hildon.StackableWindow()
-        window.set_title(config.get(self.lang, 'statistics'))
+        pannable_area = hildon.PannableArea()
+        self.pixmap = dict()
+        window.set_title(_('Statistics'))
         hildon.hildon_gtk_window_set_progress_indicator(window, 1)
-        label = gtk.Label(config.get(self.lang, 'button_statistics'))
-        vbox = gtk.VBox(True, 0)
+        label = gtk.Label(_('Sleep quality data'))
+        vbox = gtk.VBox(False, 0)
         vbox.pack_start(label, True, True, 0)
         vbox.pack_start(gtk.HSeparator(), False, False, border)
-        window.add(vbox)
+        pannable_area.add_with_viewport(vbox)
+        window.add(pannable_area)
         vbox.show()
         plots, labels, data, times = [], [], [], []
         plot_max = 0
@@ -591,7 +292,7 @@ class SleepPyPatterns(hildon.Program):
         for i in range(config.getint('user', 'index')):
             if os.path.exists(filename%i):
                 plot_max += 1
-        plot_max = min(4, plot_max)
+        plot_max = min(7, plot_max)
         for i in range(plot_max):
             data.append([])
             times.append([])
@@ -602,7 +303,7 @@ class SleepPyPatterns(hildon.Program):
             labels.append(label)
             
             drawing_area = gtk.DrawingArea()
-            drawing_area.set_size_request(800, 200)
+            drawing_area.set_size_request(800, 30)
             vbox.pack_start(drawing_area, False, True, 0)
             plots.append(drawing_area)
         
@@ -669,9 +370,9 @@ class SleepPyPatterns(hildon.Program):
                 
     
                 labels[i].set_text(labels[i].get_text()+
-                                   _(u" Сон: ")+timed(max(times[i]))+
-                                   _(u" Глубокий: ")+timed(deep_sleep_time)+
-                                   _(u" Засыпали: ")+timed(fell_asleep)
+                                   _(' Total: ')+timed(max(times[i]))+
+                                   _(' Deep: ')+timed(deep_sleep_time)+
+                                   _(' Falling asleep: ')+timed(fell_asleep)
                                    )            
             num -= 1
             
@@ -693,7 +394,7 @@ class SleepPyPatterns(hildon.Program):
         dialog = hildon.PickerDialog(self.window)
         dialog.set_transient_for(self.window)
 
-        dialog.set_title(config.get(self.lang, 'duration'))
+        dialog.set_title(_('Required sleep duration (hours)'))
         selector = hildon.TouchSelectorEntry(text=True)
         for val in config.get('user', 'used_durations').split():
             selector.append_text(str(val))
@@ -709,13 +410,13 @@ class SleepPyPatterns(hildon.Program):
                 if selector.get_current_text().strip() not in config.get('user', 'used_durations').split():
                     config.set('user', 'used_durations', selector.get_current_text().strip() +' '+
                                                 config.get('user', 'used_durations').strip())
-                widget.set_title(config.get('user', 'duration')+' '+config.get(self.lang, 'hours'))
+                widget.set_title(config.get('user', 'duration')+' '+_('hours'))
                 config.set('user', 'duration_or_alarm', 'duration')
                 duration = float(selector.get_current_text().strip())
                 nownum = time2num(str(datetime.datetime.now())[11:16])
                 self.button_time.set_title(timed((nownum + duration)%24))
             except:
-                banner = hildon.hildon_banner_show_information(widget, gtk.STOCK_CLOSE, _(u"Введите число, пожалуйста"))
+                banner = hildon.hildon_banner_show_information(widget, gtk.STOCK_CLOSE, _('Enter a number, please'))
                 banner.set_timeout(9000)
 
     #            image_statistics = gtk.image_new_from_stock(gtk.STOCK_CLOSE, gtk.ICON_SIZE_BUTTON)
@@ -726,14 +427,14 @@ class SleepPyPatterns(hildon.Program):
         
     def time_dialog(self, widget):
         dialog = hildon.Dialog()
-        dialog.set_title(config.get(self.lang, 'button_time'))
+        dialog.set_title(_('Set alarm time'))
         dialog.set_transient_for(self.window)
         time_button = hildon.TimeButton(gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
         h, m = [int(x) for x in config.get('user', 'alarm').split(':')]
         time_button.set_time(h, m)
         dialog.vbox.pack_start(time_button, True, True, border)
         dialog.vbox.pack_start(gtk.HSeparator(), False, False, border)
-        dialog.vbox.pack_start(gtk.Label(config.get(self.lang, 'interval_lable')), False, False, border)
+        dialog.vbox.pack_start(gtk.Label(_('Wake up time interval (minutes)')), False, False, border)
         bar = hildon.Seekbar()
         bar.set_total_time(60)
         bar.set_position(config.getint('user', 'window'))
@@ -758,11 +459,11 @@ class SleepPyPatterns(hildon.Program):
                 alarm_time = 24.0 - nownum + alarmnum
             else:
                 alarm_time = alarmnum - nownum
-            self.button_duration.set_title('%.2f '%alarm_time+config.get(self.lang, 'hours'))
+            self.button_duration.set_title('%.2f '%alarm_time+_('hours'))
             dialog.hide()
 
     def control_changed(self, widget, label): 
-        label.set_text(" %d %s" % (int(widget.get_value()), config.get(self.lang, 'minutes')))
+        label.set_text(" %d %s" % (int(widget.get_value()), _('minutes')))
 
     def quit(self, *args):
         self.alarm_running = False
@@ -774,20 +475,10 @@ class SleepPyPatterns(hildon.Program):
         self.window.show_all()
         gtk.main() 
 
-#    def alarm_play(self, widget=None):
-#        player = gst.element_factory_make("playbin2", "player")
-#        fakesink = gst.element_factory_make("fakesink", "fakesink")
-#        player.set_property("video-sink", fakesink)
-#        bus = player.get_bus()
-#        bus.add_signal_watch()
-#        #bus.connect("message", self.on_message)
-#        player.set_property("uri", 'file://'+config.get('user', 'mp3'))
-#        player.set_state(gst.STATE_PLAYING)
-
     def add_two_button_alarm(self, widget=None):
         event = alarm.Event()
         event.appid = 'SleepPy'
-        event.message = config.get(self.lang, 'wake_up')
+        event.message = _('Wake Up! Go, get them, Tiger!')
         event.alarm_time = time.time()
         action_stop, action_snooze = event.add_actions(2)
         action_stop.label = config.get(self.lang, 'stop')
@@ -812,7 +503,7 @@ class SleepPyPatterns(hildon.Program):
             t_old = begining_time
             filename = config.get('user', 'fileformat').replace('$', 
                                     '%')%config.getint('user', 'index')
-            self.button_alarm.set_value(config.get(self.lang, 'button_alarm_stop')+filename)
+            self.button_alarm.set_value(_('Press to stop statistics gethering\nLoggin to the file:\n')+filename)
             config.set('user', 'index', str(config.getint('user', 'index')+1))
             alarm = -config.getfloat('user', 'alarm_play_time_sec')
             diff_old = 0.0
@@ -875,7 +566,7 @@ class SleepPyPatterns(hildon.Program):
                                     
         else:
             self.alarm_running = False
-            self.button_alarm.set_value(config.get(self.lang, 'button_alarm'))
+            self.button_alarm.set_value(_('Click here to start gethering statistics'))
 
     def set_alarm_up(self):
         self.add_two_button_alarm()
